@@ -1,7 +1,10 @@
 /*
- * $Id: sc_vector.c,v 1.6 2004/06/26 06:29:20 jklein Exp $
+ * $Id: sc_vector.c,v 1.7 2004/07/10 17:04:48 jklein Exp $
  * $Author: jklein $
  * $Log: sc_vector.c,v $
+ * Revision 1.7  2004/07/10 17:04:48  jklein
+ * Added few function to sxarray_t.
+ *
  * Revision 1.6  2004/06/26 06:29:20  jklein
  * Added sort function and IO utilities.
  *
@@ -172,6 +175,24 @@ s_vector_join(svector_t *dst, svector_t *src)
 }
 
 
+#include <stdio.h>
+static void
+_s_array_dump(const char *prmpt, spointer list[], int low, int high)
+{
+	uint i;
+
+	printf("%s [%d -> %d] ", prmpt, low, high);
+
+	for (i=low; i<=high; i++)
+		printf("%s, ", (char *)list[i]);
+	printf("\n");
+}
+
+
+/**
+ * list$B$N@hF,Fs$D$N%f%K!<%/$JMWAG$N$&$ABg$-$$J}$N%$%s%G%C%/%9$rJV$9!#(B
+ * $B$9$Y$F$NMWAG$,Ey$7$$$H$-$O(B-1$B$rJV$9!#(B
+ */
 static int
 _s_vector_qsort_pivot(spointer list[], int low, int high, sc_compf_t cmpf)
 {
@@ -191,29 +212,34 @@ static void
 _s_vector_qsort(spointer list[], int low, int high, sc_compf_t cmpf)
 {
 	int p;
+	spointer tmp;
 
-	/* done */
-	if (low == high) return;
+	p = high;
+	if (high > low) {
 
-	if ((p = _s_vector_qsort_pivot(list, low, high, cmpf)) != -1) {
 		spointer x = list[p];
-		int i = low;
+		int i = low-1;
 		int j = high;
 
 		while (i <= j) {
-			while (cmpf(list[i], x) < 0) ++i;
-			while (cmpf(list[j], x) > 0) --j;
+			while (cmpf(list[++i], x) < 0) ;
+			while (j > i && cmpf(list[--j], x) > 0) ;
+
+			if (i >= j)
+				break;
 
 			/* swap */
-			if (i <= j) {
-				spointer tmp = list[i];
-				list[i] = list[j];
-				list[j] = tmp;
-				i++, j--;
-			}
+			tmp = list[i];
+			list[i] = list[j];
+			list[j] = tmp;
 		}
+
+		tmp = list[i];
+		list[i] = list[high];
+		list[high] = tmp;
+
 		_s_vector_qsort(list, low, i-1, cmpf);
-		_s_vector_qsort(list, i, high, cmpf);
+		_s_vector_qsort(list, i+1, high, cmpf);
 	}
 }
 
