@@ -1,7 +1,10 @@
 /**
- * $Id: tester.c,v 1.8 2004/06/27 13:35:17 jklein Exp $
+ * $Id: tester.c,v 1.9 2004/07/10 17:04:48 jklein Exp $
  * $Author: jklein $
  * $Log: tester.c,v $
+ * Revision 1.9  2004/07/10 17:04:48  jklein
+ * Added few function to sxarray_t.
+ *
  * Revision 1.8  2004/06/27 13:35:17  jklein
  * Added few functions for sbuffer_t and few macros for sxarray_t.
  *
@@ -109,6 +112,93 @@ sxarray_join_test(sxarray_t *dx, sxarray_t *sx)
 }
 
 
+void
+sxarray_iterator_tester(sxarray_t *xarr)
+{
+	siterator_t *itr;
+
+	s_xarray_add(xarr, "B");
+	s_xarray_add(xarr, "C");
+	s_xarray_add(xarr, "A");
+	s_xarray_add(xarr, "a");
+
+	s_xarray_sort(xarr, s_string_compare);
+
+	assert(s_xarray_size(xarr) == 4);
+	assert(strcmp(s_xarray_get(xarr, 0), "A") == 0);
+	assert(strcmp(s_xarray_get(xarr, 1), "B") == 0);
+	assert(strcmp(s_xarray_get(xarr, 2), "C") == 0);
+	assert(strcmp(s_xarray_get(xarr, 3), "a") == 0);
+
+	itr = s_xarray_iterator(xarr);
+
+	assert(strcmp(s_iterator_next(itr), "A") == 0);
+	assert(strcmp(s_iterator_next(itr), "B") == 0);
+	assert(strcmp(s_iterator_next(itr), "C") == 0);
+	assert(strcmp(s_iterator_next(itr), "a") == 0);
+
+	s_iterator_free(itr);
+
+	assert(strcmp(s_xarray_remove(xarr, 0), "A") == 0);
+	assert(strcmp(s_xarray_remove(xarr, 0), "B") == 0);
+	assert(strcmp(s_xarray_remove(xarr, 0), "C") == 0);
+	assert(strcmp(s_xarray_remove(xarr, 0), "a") == 0);
+
+}
+
+
+
+void
+sxarray_sort_tester(sxarray_t *xarr)
+{
+	assert(s_xarray_size(xarr) == 0);
+
+	s_xarray_add(xarr, "a");	s_xarray_add(xarr, "w");
+	s_xarray_add(xarr, "b");	s_xarray_add(xarr, "x");
+	s_xarray_add(xarr, "c");	s_xarray_add(xarr, "y");
+	s_xarray_add(xarr, "d");	s_xarray_add(xarr, "z");
+	s_xarray_sort(xarr, s_string_compare);
+	assert(strcmp(s_xarray_remove(xarr, 0), "a") == 0);
+	assert(strcmp(s_xarray_remove(xarr, 0), "b") == 0);
+	assert(strcmp(s_xarray_remove(xarr, 0), "c") == 0);
+	assert(strcmp(s_xarray_remove(xarr, 0), "d") == 0);
+	assert(strcmp(s_xarray_remove(xarr, 0), "w") == 0);
+	assert(strcmp(s_xarray_remove(xarr, 0), "x") == 0);
+	assert(strcmp(s_xarray_remove(xarr, 0), "y") == 0);
+	assert(strcmp(s_xarray_remove(xarr, 0), "z") == 0);
+
+
+	s_xarray_add(xarr, "a");	s_xarray_add(xarr, "w");
+	s_xarray_sort(xarr, s_string_compare);
+	assert(strcmp(s_xarray_remove(xarr, 0), "a") == 0);
+	assert(strcmp(s_xarray_remove(xarr, 0), "w") == 0);
+
+	
+	s_xarray_add(xarr, "a");	s_xarray_add(xarr, "b");
+	s_xarray_add(xarr, "c");	s_xarray_add(xarr, "d");
+	s_xarray_sort(xarr, s_string_compare);
+	assert(strcmp(s_xarray_remove(xarr, 0), "a") == 0);
+	assert(strcmp(s_xarray_remove(xarr, 0), "b") == 0);
+	assert(strcmp(s_xarray_remove(xarr, 0), "c") == 0);
+	assert(strcmp(s_xarray_remove(xarr, 0), "d") == 0);
+
+	s_xarray_add(xarr, "b");	s_xarray_add(xarr, "a");
+	s_xarray_sort(xarr, s_string_compare);
+	assert(strcmp(s_xarray_remove(xarr, 0), "a") == 0);
+	assert(strcmp(s_xarray_remove(xarr, 0), "b") == 0);
+
+	s_xarray_add(xarr, "a");	s_xarray_add(xarr, "b");
+	s_xarray_add(xarr, "b");	s_xarray_add(xarr, "a");
+	s_xarray_sort(xarr, s_string_compare);
+	assert(strcmp(s_xarray_remove(xarr, 0), "a") == 0);
+	assert(strcmp(s_xarray_remove(xarr, 0), "a") == 0);
+	assert(strcmp(s_xarray_remove(xarr, 0), "b") == 0);
+	assert(strcmp(s_xarray_remove(xarr, 0), "b") == 0);
+
+
+}
+
+
 void
 sxarray_tester(sxarray_t *xarr)
 {
@@ -116,9 +206,11 @@ sxarray_tester(sxarray_t *xarr)
 
 	assert(xarr->size(xarr) == 0);
 
-	s_xarray_add(xarr, "A");
 	s_xarray_add(xarr, "B");
 	s_xarray_add(xarr, "C");
+	s_xarray_add(xarr, "A");
+
+	s_xarray_sort(xarr, s_string_compare);
 
 	assert(s_xarray_size(xarr) == 3);
 	assert(strcmp(s_xarray_get(xarr, 0), "A") == 0);
@@ -141,6 +233,13 @@ sxarray_tester(sxarray_t *xarr)
 
 	s_xarray_free(vx);
 	s_xarray_free(lx);
+
+	/* iterator test */
+	assert(s_xarray_size(xarr) == 0);
+	sxarray_iterator_tester(xarr);
+
+	/* sort test */
+	sxarray_sort_tester(xarr);
 }
 
 
